@@ -1,7 +1,7 @@
 # ABSTRACT: turn WGS84 coordinates into three word addresses and vice-versa using what3words.com HTTPS API
 
 package Geo::What3Words;
-$Geo::What3Words::VERSION = '2.1.5';
+$Geo::What3Words::VERSION = '2.1.6';
 use strict;
 use warnings;
 use Cpanel::JSON::XS;
@@ -145,13 +145,13 @@ sub _query_remote_api {
   $self->_log("GET $url");
   my $response = $self->{ua}->get($url);
 
-  if ( ! $response->is_success) {
-    warn "got failed response from $url: " . $response->status_line;
-    $self->_log("got failed response from $url: " . $response->status_line);
+  if ( ! $response->{success}) {
+    warn "got failed response from $url: " . $response->{status};
+    $self->_log("got failed response from $url: " . $response->{status});
     return;
   }
 
-  my $json = $response->content;
+  my $json = $response->{content};
   $json = decode_utf8($json);
   $self->_log($json);
 
@@ -188,7 +188,7 @@ Geo::What3Words - turn WGS84 coordinates into three word addresses and vice-vers
 
 =head1 VERSION
 
-version 2.1.5
+version 2.1.6
 
 =head1 SYNOPSIS
 
